Crate point_like
source ·Traits
- A number that may be compared for approximate equality.
- A point-like type that can be converted to and from
[F; 2]. - A point-like type that can be used to define a coordinate in 2D space.
- A trait for rounding scalars.